// Tide Protocol - Infrastructure for the Personal Data economy
// Copyright (C) 2019 Tide Foundation Ltd
// 
// This program is free software and is subject to the terms of 
// the Tide Community Open Source License as published by the 
// Tide Foundation Limited. You may modify it and redistribute 
// it in accordance with and subject to the terms of that License.
// This program is distributed WITHOUT WARRANTY of any kind, 
// including without any implied warranty of MERCHANTABILITY or 
// FITNESS FOR A PARTICULAR PURPOSE.
// See the Tide Community Open Source License for more details.
// You should have received a copy of the Tide Community Open 
// Source License along with this program.
// If not, see https://tide.org/licenses_tcosl-1-0-en

import EcKeyBase from './ecKeyBase';
import CP256Point, { curve } from './cP256Point';

/** @extends {EcKeyBase<CP256Point,CP256Key>} */
export default class CP256Key extends EcKeyBase {
    /**
     * @param {import('./bnInput').BNInput} x
     * @param {CP256Point} y
     */
    constructor(x, y) {
        super(x, y);
    }
    
    get _point() {
        return CP256Point;
    };

    get _new() {
        return CP256Key;
    };

    get curve() {
        return curve;
    };

    /**
     * @param {import('./bnInput').BNInput} x
     * @param {boolean} noPublic
     */
    static private(x, noPublic = false) {
        return EcKeyBase._private(CP256Key, x, noPublic);
    }

    static generate() {
        return EcKeyBase._generate(CP256Key);
    }

    /** @param {string | Uint8Array} data */
    static from(data) {
        return EcKeyBase._from(CP256Key, data);
    }
}
