import assert from 'assert';
import index from '../index.js';

const bits = 32;
const msg = "In cryptography, the ElGamal encryption system is an asymmetric key encryption algorithm for public-key cryptography which is based on the Diffie–Hellman key exchange. The system provides an additional layer of security by asymmetrically encrypting keys previously used for symmetric message encryption";
describe('Cryptide', function () {
    describe('encrypt()', function () {
        describe('decrypt()', function () {
            it('should reconstruct message', function () {
                const [prv, pub] = index.getKeys(bits);
                const cypherText = index.encrypt(msg, pub);
                const secretText = index.decrypt(cypherText, prv);
                assert.equal(msg, secretText)
            });
        });
    });

    describe('shareKey()', function () {
        const number = 5;
        const threshold = 3;

        describe('combine()', function () {
            it('reconstruct key shares', function () {
                for (let i = 0; i < 25; i++) {
                    const [prv] = index.getKeys(bits);
                    const sharedKeys = index.shareKey(prv, number, threshold).slice(-threshold)
                    const joinedKey = index.combineKeys(sharedKeys)
                    assert.equal(prv.toString(), joinedKey.toString())
                }
            });
        });

        describe('combinePartial()', function () {
            it('reconstruct partial descriptions', function () {
                for (let i = 0; i < 25; i++) {
                    const [prv, pub] = index.getKeys(bits);
                    const cypher = index.encrypt(msg, pub);

                    const sharedKeys = index.shareKey(prv, number, threshold).slice(-threshold)
                    const partialCypher = sharedKeys.map(sh => index.decryptPartial(cypher, sh));

                    var joinedMsg = index.combineDeciphers(partialCypher, pub);
                    assert.equal(msg, joinedMsg)
                }
            });
        });

        describe('combineTexts()', function () {
            it('reconstruct text shares', function () {
                for (let i = 0; i < 5; i++) {
                    const shares = index.shareText(msg, number, threshold);
                    const joinedMsg = index.combineTexts(shares.slice(-threshold));
                    assert.equal(msg, joinedMsg)                    
                }
            });
        });
    });
});
